"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConfigurationError = void 0;
const ErrorSerialiser_1 = require("../ErrorSerialiser");
const RuntimeError_1 = require("./RuntimeError");
/**
 * Thrown to indicate that a test framework or test suite configuration error occurred.
 *
 * @group Errors
 */
class ConfigurationError extends RuntimeError_1.RuntimeError {
    static fromJSON(serialised) {
        const error = new ConfigurationError(serialised.message, ErrorSerialiser_1.ErrorSerialiser.deserialise(serialised.cause));
        error.stack = serialised.stack;
        return error;
    }
    /**
     * @param message - Human-readable description of the error
     * @param [cause] - The root cause of this [`RuntimeError`](https://serenity-js.org/api/core/class/RuntimeError/), if any
     */
    constructor(message, cause) {
        super(ConfigurationError, message, cause);
    }
}
exports.ConfigurationError = ConfigurationError;
//# sourceMappingURL=ConfigurationError.js.map