"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LogicError = void 0;
const ErrorSerialiser_1 = require("../ErrorSerialiser");
const RuntimeError_1 = require("./RuntimeError");
/**
 * Thrown to indicate that an [`Interaction`](https://serenity-js.org/api/core/class/Interaction/), a [`Task`](https://serenity-js.org/api/core/class/Task/) or a test scenario
 * can't be executed due to a logical error.
 *
 * For example, it's not possible to assert on the last HTTP Response if the request
 * hasn't been performed yet.
 *
 * @group Errors
 */
class LogicError extends RuntimeError_1.RuntimeError {
    static fromJSON(serialised) {
        const error = new LogicError(serialised.message, ErrorSerialiser_1.ErrorSerialiser.deserialise(serialised.cause));
        error.stack = serialised.stack;
        return error;
    }
    /**
     * @param message - Human-readable description of the error
     * @param [cause] - The root cause of this [`RuntimeError`](https://serenity-js.org/api/core/class/RuntimeError/), if any
     */
    constructor(message, cause) {
        super(LogicError, message, cause);
    }
}
exports.LogicError = LogicError;
//# sourceMappingURL=LogicError.js.map