"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OperationInterruptedError = void 0;
const ErrorSerialiser_1 = require("../ErrorSerialiser");
const RuntimeError_1 = require("./RuntimeError");
/**
 * Thrown to indicate that a [scheduled operation](https://serenity-js.org/api/core/class/Scheduler/)
 * has been stopped before it was completed.
 *
 * @group Errors
 */
class OperationInterruptedError extends RuntimeError_1.RuntimeError {
    static fromJSON(serialised) {
        const error = new OperationInterruptedError(serialised.message, ErrorSerialiser_1.ErrorSerialiser.deserialise(serialised.cause));
        error.stack = serialised.stack;
        return error;
    }
    /**
     * @param message
     *  Human-readable description of the error
     *
     * @param [cause]
     *  The root cause of this [`RuntimeError`](https://serenity-js.org/api/core/class/RuntimeError/), if any
     */
    constructor(message, cause) {
        super(OperationInterruptedError, message, cause);
    }
}
exports.OperationInterruptedError = OperationInterruptedError;
//# sourceMappingURL=OperationInterruptedError.js.map