"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TimeoutExpiredError = void 0;
const ErrorSerialiser_1 = require("../ErrorSerialiser");
const RuntimeError_1 = require("./RuntimeError");
/**
 * Thrown to indicate that an [`Interaction`](https://serenity-js.org/api/core/class/Interaction/), a [`Task`](https://serenity-js.org/api/core/class/Task/) or a test scenario
 * took longer to execute than the expected timeout.
 *
 * @group Errors
 */
class TimeoutExpiredError extends RuntimeError_1.RuntimeError {
    static fromJSON(serialised) {
        const error = new TimeoutExpiredError(serialised.message, ErrorSerialiser_1.ErrorSerialiser.deserialise(serialised.cause));
        error.stack = serialised.stack;
        return error;
    }
    /**
     * @param message
     *  Human-readable description of the error
     *
     * @param [cause]
     *  The root cause of this [`RuntimeError`](https://serenity-js.org/api/core/class/RuntimeError/), if any
     */
    constructor(message, cause) {
        super(TimeoutExpiredError, message, cause);
    }
}
exports.TimeoutExpiredError = TimeoutExpiredError;
//# sourceMappingURL=TimeoutExpiredError.js.map