"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ActorStageExitAttempted = void 0;
const tiny_types_1 = require("tiny-types");
const model_1 = require("../../model");
const screenplay_1 = require("../../screenplay");
const AsyncOperationAttempted_1 = require("../AsyncOperationAttempted");
/**
 * Emitted when an [`Actor`](https://serenity-js.org/api/core/class/Actor/) is dismissed
 * either upon the [`SceneFinishes`](https://serenity-js.org/api/core-events/class/SceneFinishes/) event
 * for actors initialised within the scope of a test scenario,
 * or upon the [`TestRunFinishes`](https://serenity-js.org/api/core-events/class/TestRunFinishes/) event
 * for actors initialised within the scope of a test suite.
 *
 * @group Events
 */
class ActorStageExitAttempted extends AsyncOperationAttempted_1.AsyncOperationAttempted {
    actor;
    static fromJSON(o) {
        return new ActorStageExitAttempted(model_1.CorrelationId.fromJSON(o.correlationId), model_1.Name.fromJSON(o.actor), screenplay_1.Timestamp.fromJSON(o.timestamp));
    }
    constructor(correlationId, actor, timestamp) {
        (0, tiny_types_1.ensure)('actor', actor, (0, tiny_types_1.isDefined)());
        super(new model_1.Name('Stage'), new model_1.Description(`Actor ${actor.value} exits the stage`), correlationId, timestamp);
        this.actor = actor;
    }
}
exports.ActorStageExitAttempted = ActorStageExitAttempted;
//# sourceMappingURL=ActorStageExitAttempted.js.map