"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ActorStageExitCompleted = void 0;
const tiny_types_1 = require("tiny-types");
const model_1 = require("../../model");
const screenplay_1 = require("../../screenplay");
const AsyncOperationCompleted_1 = require("../AsyncOperationCompleted");
/**
 * Emitted when an [`Actor`](https://serenity-js.org/api/core/class/Actor/) and its abilities
 * are correctly [released](https://serenity-js.org/api/core/interface/Discardable/) either
 * upon the [`SceneFinishes`](https://serenity-js.org/api/core-events/class/SceneFinishes/) event
 * for actors initialised within the scope of a test scenario,
 * or upon the [`TestRunFinishes`](https://serenity-js.org/api/core-events/class/TestRunFinishes/) event
 * for actors initialised within the scope of a test suite.
 *
 * @group Events
 */
class ActorStageExitCompleted extends AsyncOperationCompleted_1.AsyncOperationCompleted {
    actor;
    static fromJSON(o) {
        return new ActorStageExitCompleted(model_1.CorrelationId.fromJSON(o.correlationId), model_1.Name.fromJSON(o.actor), screenplay_1.Timestamp.fromJSON(o.timestamp));
    }
    constructor(correlationId, actor, timestamp) {
        super(correlationId, timestamp);
        this.actor = actor;
        (0, tiny_types_1.ensure)('actor', actor, (0, tiny_types_1.isDefined)());
    }
}
exports.ActorStageExitCompleted = ActorStageExitCompleted;
//# sourceMappingURL=ActorStageExitCompleted.js.map