"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ActorStageExitStarts = void 0;
const tiny_types_1 = require("tiny-types");
const model_1 = require("../../model");
const screenplay_1 = require("../../screenplay");
const DomainEvent_1 = require("../DomainEvent");
/**
 * Emitted upon the [`SceneFinishes`](https://serenity-js.org/api/core-events/class/SceneFinishes/) and
 * [`TestRunFinishes`](https://serenity-js.org/api/core-events/class/TestRunFinishes/) events
 * to notify the [stage crew members](https://serenity-js.org/api/core/interface/StageCrewMember/)
 * about the final state of the [actors](https://serenity-js.org/api/core/class/Actor/) and their abilities
 * before they're [released](https://serenity-js.org/api/core/interface/Discardable/).
 *
 * @group Events
 */
class ActorStageExitStarts extends DomainEvent_1.DomainEvent {
    sceneId;
    actor;
    static fromJSON(o) {
        return new ActorStageExitStarts(model_1.CorrelationId.fromJSON(o.sceneId), o.actor, screenplay_1.Timestamp.fromJSON(o.timestamp));
    }
    constructor(sceneId, actor, timestamp) {
        super(timestamp);
        this.sceneId = sceneId;
        this.actor = actor;
        (0, tiny_types_1.ensure)('sceneId', sceneId, (0, tiny_types_1.isDefined)());
        (0, tiny_types_1.ensure)('actor', actor, (0, tiny_types_1.isDefined)());
    }
}
exports.ActorStageExitStarts = ActorStageExitStarts;
//# sourceMappingURL=ActorStageExitStarts.js.map