"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Tags = void 0;
const tiny_types_1 = require("tiny-types");
const _1 = require("./");
/**
 * @package
 */
class Tags {
    static Pattern = /^@([\w-]+)[\s:]?(.*)/i;
    static matchTags(tagText) {
        if (tagText === '') {
            return [];
        }
        const [, tagType, value] = Tags.Pattern.exec(tagText);
        return (0, tiny_types_1.match)(tagType.toLowerCase())
            .when('manual', _ => [new _1.ManualTag()])
            .when(/^issues?$/, _ => value.split(',').map(value => new _1.IssueTag(value.trim())))
            .else(value => [new _1.ArbitraryTag(value.trim())]);
    }
    static from(text) {
        const tags = text.split(/\s+/)
            .filter(word => word.startsWith('@'))
            .flatMap(tag => Tags.matchTags(tag));
        return tags ?? Tags.matchTags(text);
    }
    static stripFrom(text) {
        return text.split(/\s+/)
            .map(word => Tags.Pattern.test(word) ? undefined : word)
            .filter(Boolean)
            .join(' ')
            .trim();
    }
}
exports.Tags = Tags;
//# sourceMappingURL=Tags.js.map