import type { ListensToDomainEvents } from './ListensToDomainEvents';
import type { StageCrewMemberBuilderDependencies } from './StageCrewMemberBuilderDependencies';

/**
 * Use a [`StageCrewMember`](https://serenity-js.org/api/core/interface/StageCrewMemberBuilder/) to configure complex [`StageCrewMember`](https://serenity-js.org/api/core/interface/StageCrewMember/) objects.
 *
 * Useful when you're interested in implementing custom reporters with multiple configuration options.
 * See [`ConsoleReporter`](https://serenity-js.org/api/console-reporter/class/ConsoleReporter/) for an example.
 *
 * ## Learn more
 * - [`StageCrewMember`](https://serenity-js.org/api/core/interface/StageCrewMember/)
 * - [`StageCrewMemberBuilderDependencies`](https://serenity-js.org/api/core/interface/StageCrewMemberBuilderDependencies/)
 * - [`SerenityConfig.crew`](https://serenity-js.org/api/core/class/SerenityConfig/#crew)
 *
 * @group Stage
 */
export interface StageCrewMemberBuilder<T extends ListensToDomainEvents = ListensToDomainEvents> {

    /**
     * Instantiates a [`StageCrewMember`](https://serenity-js.org/api/core/interface/StageCrewMember/), giving it access to shared dependencies
     * such as [`Stage`](https://serenity-js.org/api/core/class/Stage/) or [`OutputStream`](https://serenity-js.org/api/core-adapter/interface/OutputStream/)
     */
    build(dependencies: StageCrewMemberBuilderDependencies): T;
}
